macro_rules! ash {
( $( $cmd:tt )* ) => { ... };
}Expand description
Macro to execute the given command using the Almquist Shell.
macro_rules! ash {
( $( $cmd:tt )* ) => { ... };
}Macro to execute the given command using the Almquist Shell.